==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgs, _super);
    function DomainChartSeriesPointerEventArgs(a, b, c) {
        var _this = _super.call(this) || this;
        _this.c = { $type: Point_$type, x: NaN, y: NaN };
        _this._series = null;
        _this._item = null;
        _this._plotAreaPosition = null;
        _this.series = a;
        _this.item = b;
        _this.plotAreaPosition = c;
        return _this;
    }
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "series", {
        get: function () {
            return this._series;
        },
        set: function (a) {
            this._series = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "item", {
        get: function () {
            return this._item;
        },
        set: function (a) {
            this._item = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return this._plotAreaPosition;
        },
        set: function (a) {
            this._plotAreaPosition = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "chartPosition", {
        get: function () {
            if (isNaN_(this.c.x) && isNaN_(this.c.y)) {
                this.c.x = this.plotAreaPosition.x - this.series.c7.v0.left;
                this.c.y = this.plotAreaPosition.y - this.series.c7.v0.top;
            }
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartSeriesPointerEventArgs.$t = markType(DomainChartSeriesPointerEventArgs, 'DomainChartSeriesPointerEventArgs');
    return DomainChartSeriesPointerEventArgs;
}(Base));
export { DomainChartSeriesPointerEventArgs };

==> igniteui-react-charts-19.0.0.tgz: package/esm5/lib/DomainChartSeriesPointerEventArgs.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, Point_$type, markType } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var DomainChartSeriesPointerEventArgs = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DomainChartSeriesPointerEventArgs, _super);
    function DomainChartSeriesPointerEventArgs(a, b, c) {
        var _this = _super.call(this) || this;
        _this.e = { $type: Point_$type, x: NaN, y: NaN };
        _this._series = null;
        _this._item = null;
        _this._plotAreaPosition = null;
        _this.b = false;
        _this.series = a;
        _this.item = b;
        _this.plotAreaPosition = c;
        return _this;
    }
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "series", {
        get: function () {
            return this._series;
        },
        set: function (a) {
            this._series = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "item", {
        get: function () {
            return this._item;
        },
        set: function (a) {
            this._item = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return this._plotAreaPosition;
        },
        set: function (a) {
            this._plotAreaPosition = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "chartPosition", {
        get: function () {
            if (isNaN_(this.e.x) && isNaN_(this.e.y)) {
                this.e.x = this.plotAreaPosition.x - this.series.da.wz.left;
                this.e.y = this.plotAreaPosition.y - this.series.da.wz.top;
            }
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DomainChartSeriesPointerEventArgs.prototype, "cancelSelection", {
        get: function () {
            return this.b;
        },
        set: function (a) {
            this.b = a;
        },
        enumerable: false,
        configurable: true
    });
    DomainChartSeriesPointerEventArgs.$t = markType(DomainChartSeriesPointerEventArgs, 'DomainChartSeriesPointerEventArgs');
    return DomainChartSeriesPointerEventArgs;
}(Base));
export { DomainChartSeriesPointerEventArgs };
